import {} from './RequestSenderInterface.js';
export class HttpRequestSender {
    /**
     * Sends a HTTP request to a given URL.
     *
     * @param {string} url - The endpoint URL
     * @param {RequestInit} options - The request options (method, headers, body, etc.)
     * @returns {Promise<Response>} - A promise that resolves to the response
     */
    async send(url, options = {}) {
        console.log('Sending request to URL:', url);
        console.log('Request options:', {
            headers: options.headers,
            method: options.method,
            bodyLength: options.body ? options.body.length : 0
        });
        return fetch(url, {
            ...options
        })
            .catch(error => {
            console.error('Failed to send request:', JSON.stringify(error, null, 2));
            // Handle the exception and return a custom Response object
            const responseInit = {
                status: 500,
                statusText: error.message
            };
            // Return a Response object with an appropriate error message
            return new Response(null, responseInit);
        });
    }
}
